==> kubernetes-model-events-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/events/v1/EventListBuilder.java <==
package io.fabric8.kubernetes.api.model.events.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EventListBuilder extends EventListFluentImpl<EventListBuilder> implements VisitableBuilder<EventList,EventListBuilder>{
  public EventListBuilder() {
    this(false);
  }
  public EventListBuilder(Boolean validationEnabled) {
    this(new EventList(), validationEnabled);
  }
  public EventListBuilder(EventListFluent<?> fluent) {
    this(fluent, false);
  }
  public EventListBuilder(EventListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EventList(), validationEnabled);
  }
  public EventListBuilder(EventListFluent<?> fluent,EventList instance) {
    this(fluent, instance, false);
  }
  public EventListBuilder(EventListFluent<?> fluent,EventList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EventListBuilder(EventList instance) {
    this(instance,false);
  }
  public EventListBuilder(EventList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  EventListFluent<?> fluent;
  Boolean validationEnabled;
  public EventList build() {
    EventList buildable = new EventList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-events-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/events/v1/EventListBuilder.java <==
package io.fabric8.kubernetes.api.model.events.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EventListBuilder extends EventListFluent<EventListBuilder> implements VisitableBuilder<EventList,EventListBuilder>{
  public EventListBuilder() {
    this(false);
  }
  public EventListBuilder(Boolean validationEnabled) {
    this(new EventList(), validationEnabled);
  }
  public EventListBuilder(EventListFluent<?> fluent) {
    this(fluent, false);
  }
  public EventListBuilder(EventListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EventList(), validationEnabled);
  }
  public EventListBuilder(EventListFluent<?> fluent,EventList instance) {
    this(fluent, instance, false);
  }
  public EventListBuilder(EventListFluent<?> fluent,EventList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new EventList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EventListBuilder(EventList instance) {
    this(instance,false);
  }
  public EventListBuilder(EventList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new EventList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  EventListFluent<?> fluent;
  Boolean validationEnabled;
  public EventList build() {
    EventList buildable = new EventList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
